Expression Utilities
====================

A series of utilities are provided to work with expressions in a more convenient way.

Functions
---------

.. autosummary::
   :toctree: autofiles/utilities
   :nosignatures:

    blosc2.evaluate
    blosc2.get_expr_operands
    blosc2.validate_expr

Decorators
----------

.. autosummary::
   :toctree: autofiles/utilities
   :nosignatures:

    blosc2.jit
